MatertinoBottomSheetRadio class

Inheritance

Constructors

MatertinoBottomSheetRadio({Key? key, required Widget child, required List list, String? selected, required Function onSelect, String heading = 'Select', double height = 0.8, Color? radioColor, TextStyle? headingStyle, bool isSearchEnable = true, Color? selectedRadioColor, TextStyle? radioTextStyle, double? radioTextSpacing, EdgeInsetsGeometry? contentPadding, double? radioSize, String? doneButtonText, TextStyle? doneTextStyle, BoxDecoration? searchFieldDecoration, TextStyle? searchPlaceholderStyle, TextStyle? searchTextStyle, Color? borderColor, bool selectOnRadioTap = false, double? borderWidth, int radioTextMaximumLine = 2, IconData? selectedRadioIconData, IconData? unselectedRadioIconData, Widget? trailingWidget, Color? tileColor})
const

Properties

borderColor Color?
List Tile Border Color
final
borderWidth double?
List Tile Border Width
final
child Widget
Any Widget
final
contentPadding EdgeInsetsGeometry?
List Title Padding
final
doneButtonText String?
Finish Button Text
final
doneTextStyle TextStyle?
Finish Button Text Style
final
hashCode int
The hash code for this object.
no setterinherited
heading String
Bottom Sheet Title
final
headingStyle TextStyle?
Bottom Sheet Heading Style
final
height double
Bottom Sheet Height
final
isSearchEnable bool
Show/Hide Search Feature
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
list List
Item List
final
onSelect Function
On Select Callback Function
final
radioColor Color?
Radio Icon Color
final
radioSize double?
Radio Icon Size
final
radioTextMaximumLine int
Title Maximum Line
final
radioTextSpacing double?
Spacing Between Icon and Title
final
radioTextStyle TextStyle?
Radio Text Style
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchFieldDecoration BoxDecoration?
Search Field Decoration
final
searchPlaceholderStyle TextStyle?
Search Field Placeholder
final
searchTextStyle TextStyle?
Search Input Text Style
final
selected String?
Selected Value
final
selectedRadioColor Color?
Selected Radio Color
final
selectedRadioIconData IconData?
Selected Radio Icon
final
selectOnRadioTap bool
Enable/Disable On Radio Tap Select
final
tileColor Color?
Tile Background Color
final
trailingWidget Widget?
Trailing Widget
final
unselectedRadioIconData IconData?
Un-Selected Radio Icon
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MatertinoBottomSheetRadio>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited