MatertinoRadioListTile<T> class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- MatertinoRadioListTile
Constructors
-
MatertinoRadioListTile({Key? key, required T value, Color? radioColor, Color? selectedRadioColor, required T groupValue, required ValueChanged<
T?> onChanged, double? radioTextSpacing, required String title, TextStyle? titleStyle, EdgeInsetsGeometry? contentPadding, double? radioSize, Color? borderColor, double? borderWidth, IconData? selectedRadioIconData, IconData? unselectedRadioIconData, Widget? trailingWidget, Color? tileColor}) -
const
Properties
- borderColor → Color?
-
List Tile Border Color
final
- borderWidth → double?
-
List Tile Border Width
final
- contentPadding → EdgeInsetsGeometry?
-
List Title Padding
final
- groupValue → T
-
Group Value
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onChanged
→ ValueChanged<
T?> -
OnTap Change
final
- radioColor → Color?
-
Radio Icon Color
final
- radioSize → double?
-
Radio Icon Size
final
- radioTextSpacing → double?
-
Spacing Between Icon and Title
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedRadioColor → Color?
-
Selected Radio Color
final
- selectedRadioIconData → IconData?
-
Selected Radio Icon
final
- tileColor → Color?
-
Tile Background Color
final
- title → String
-
List Title
final
- titleStyle → TextStyle?
-
List Title Style
final
- trailingWidget → Widget?
-
Trailing Widget
final
- unselectedRadioIconData → IconData?
-
Un-Selected Radio Icon
final
- value → T
-
Selected Value
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
customRadioIcon(
BuildContext context) → Widget -
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited